pilas.habilidades.SeMantieneEnPantalla

Package pilas :: Module habilidades :: Class SeMantieneEnPantalla |
[hide private]
[frames] | no frames]

# Class SeMantieneEnPantalla

source code

    object --+
             |
     Habilidad --+
                 |
                SeMantieneEnPantalla

Se asegura de que el actor regrese a la pantalla si sale o que no salga en nigún momento de la pantalla.

Si el actor sale por la derecha de la pantalla, entonces regresa por la izquiera. Si sale por arriba regresa por abajo y asi...

Instance Methods | [hide private]
__init__(self, receptor, permitir_salida=True) Inicializa la habilidad. | source code
actualizar(self) | source code
Inherited from `Habilidad`: `eliminar` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, receptor, permitir_salida=True) (Constructor) | source code
Inicializa la habilidad. :param receptor: El actor que aprenderá la habilidad. :param permitir_salida: Valor booleano que establece si el actor puede salir por los lados de la ventana y regresar por el lado opuesto. Si se establece a False, el actor no puede salir de la ventana en ningún momento. Overrides: object.__init__

### actualizar(self) | source code
Overrides: Habilidad.actualizar